@@ -137,6 +137,13 @@ mediaShow.loadSlide = function (slideshow, slideNumber)
         }
         
         slide.loaded = mediaShow.LOADED;
+        
+        $(slideContainer).touchwipe({
+            wipeLeft: function() {mediaShow.prev(mediaShow.indexOf(slideshow)) },
+            wipeRight: function() { mediaShow.next(mediaShow.indexOf(slideshow)) },
+            preventDefaultEvents: false
+            });
+        
         mediaShow.loadNext(slideshow);
     });
 }
